@@ -137,7 +137,7 @@ def installed(args) -> None:
 @as_command
 def fab(args) -> None:
     '''
-    drop to Fabric
+    Drop to Fabric
     '''
     os.system(prefix + 'fab %s' % ' '.join(sys.argv[2:]))
 
@@ -145,7 +145,7 @@ def fab(args) -> None:
 @as_command
 def test(args) -> None:
     '''
-    run unittest
+    Run unittest with nosetests
     '''
     return os.system(prefix + 'nosetests -sv')
 
@@ -163,19 +163,19 @@ def coverage(args) -> None:
 def run(args) -> None:
     '''
     Exec file locally or remote
-    @argument --remote, help=run as remote file
+    @argument --remote, metavar=remote, help=run as remote file
     '''
     if args.remote:
+        return os.system('require run %s' % args.remote)
+    else:
         python = config.load().get('python', 'python')
         return os.system(prefix + '%s %s' % (python, ' '.join(sys.argv[2:])))
-    else:
-        return os.system('require run %s' % args.remote)
 
 
 @as_command
 def python(args) -> None:
     '''
-    run python
+    Run python
     '''
     python = config.load().get('python', 'python')
     return os.system(prefix + '%s %s' % (python, ' '.join(sys.argv[2:])))
@@ -184,15 +184,15 @@ def python(args) -> None:
 @as_command
 def repl(args) -> None:
     '''
-    call ipython as repl
+    Call ipython as repl
     '''
-    return os.system(prefix + 'ipython')
+    return os.system(prefix + 'ipython' % ' '.join(sys.argv[2:]))
 
 
 @as_command
 def pip(args) -> None:
     '''
-    call pip
+    Call pip
     '''
     return os.system(prefix + 'pip %s' % ' '.join(sys.argv[2:]))
 
@@ -200,7 +200,7 @@ def pip(args) -> None:
 @as_command
 def doc(args) -> None:
     '''
-    audto gen document
+    Auto gen document
     '''
     return os.system('sphinx-apidoc ./ -o ./docs -f -M -F')
 
@@ -247,8 +247,8 @@ def main():
     try:
         router(pattern, sys.argv)
     except Exception as ex:
-        util.error("Exception <%s>, Traceback:")
-        map(util.error, (str(ex), traceback.format_exc()))
+        util.error("Exception <%s>, Traceback:" % str(ex))
+        util.error(traceback.format_exc())
 
 if __name__ == '__main__':
     if sys.version_info[:2] < (3, 5) and sys.argv[-1] == 'install':
